==> syncthingtray_1.2.2.orig.tar.gz: syncthingtray-1.2.2/tray/translations/syncthingtray_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation>复制名字</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation>复制 ID</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation>复制 标签/ID</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation>重新扫描</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation>复制 标签/ID</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation>全部重新扫描</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation>日志</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation>显示内部错误</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation>从 Syncthing 断开连接</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation>启动器错误</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation>Syncthing 通知 - 点击解除</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation>Syncthing 设备想要连接 - 点击打开网页 UI</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing directory - click for web UI</source>
        <translation>新 Syncthing 目录 - 点击打开网页 UI</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation>Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="392"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="71"/>
        <location filename="../gui/traywidget.cpp" line="743"/>
        <location filename="../gui/traywidget.cpp" line="785"/>
        <source>Start</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="97"/>
        <location filename="../gui/traywidget.cpp" line="269"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="110"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="123"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="212"/>
        <source>Global</source>
        <translation>全局</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="219"/>
        <source>Global overall statistics</source>
        <translation>全局总体数据</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="222"/>
        <location filename="../gui/traywidget.ui" line="242"/>
        <location filename="../gui/traywidget.ui" line="293"/>
        <location filename="../gui/traywidget.ui" line="313"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="229"/>
        <source>Local</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="239"/>
        <source>Local overall statistics</source>
        <translation>本地总体数据</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="283"/>
        <source>In</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="290"/>
        <source>Incoming traffic</source>
        <translation>下载流量</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="300"/>
        <source>Out</source>
        <translation>上传</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="310"/>
        <source>Outgoing traffic</source>
        <translation>上传流量</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation>点击显示&lt;i&gt;新&lt;/i&gt;通知&lt;br&gt;
 对于&lt;i&gt;所有&lt;/i&gt;通知，请查看日志</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="354"/>
        <location filename="../gui/traywidget.cpp" line="148"/>
        <location filename="../gui/traywidget.cpp" line="312"/>
        <source>New notifications</source>
        <translation>新通知</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="384"/>
        <source>Directories</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="416"/>
        <source>Devices</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="448"/>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="476"/>
        <source>Recent changes</source>
        <translation>最后更改</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="512"/>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="522"/>
        <source>Dismiss</source>
        <translation>解除</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="120"/>
        <source>View own device ID</source>
        <translation>查看本设备 ID</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="125"/>
        <source>Restart Syncthing</source>
        <translation>重启 Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="130"/>
        <source>Show Syncthing log</source>
        <translation>显示 Syncthing 日志</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="135"/>
        <source>Rescan all directories</source>
        <translation>重新扫描全部目录</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="142"/>
        <source>Connection</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="164"/>
        <source>Show internal errors</source>
        <translation>显示内部错误</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="179"/>
        <source>Quit Syncthing Tray</source>
        <translation>退出 Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="367"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation>您真的想要重启 Syncthing 吗？</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="393"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation>未连接至 Syncthing，点击连接</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="405"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="406"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation>Syncthing 运行中，点击暂停全部设备</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="411"/>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="412"/>
        <source>At least one device is paused, click to resume</source>
        <translation>至少有一个设备已暂停，点击恢复</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="517"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation>指定的连接配置 &lt;em&gt;%1&lt;/em&gt; 没有定义，因此被忽略。</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="547"/>
        <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>本地设备上不存在目录 &lt;i&gt;%1&lt;/i&gt;。</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="558"/>
        <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>本地设备上不存在包含目录 &lt;i&gt;%1&lt;/i&gt;。</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="601"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="605"/>
        <source>Copy device ID</source>
        <translation>复制设备 ID</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="608"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="739"/>
        <location filename="../gui/traywidget.cpp" line="779"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="740"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation>停止通过托盘图标启动 Syncthing 实例</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="744"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation>使用设置中配置的内置启动器启动 Syncthing</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="57"/>
        <source>Unable to </source>
        <translation>无法 </translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="90"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation>系统托盘当前不可用。不过，您可以使用 --windowed 将托盘菜单作为常规窗口打开。也可以使用 --wait 启动 Syncthing Tray 以等待系统托盘可用，而不是显示此消息。</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="114"/>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation>首次使用 Syncthing Tray 时，您必须配置如何连接到 Syncthing。</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="115"/>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation>请注意，设置对话框允许从本地 Syncthing 配置导入 URL、凭据和 API 密钥。</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="124"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation>Qt 库没有使用托盘图标支持构建。不过，您可以使用 -w 将托盘菜单作为常规窗口打开。</translation>
    </message>
</context>
</TS>

==> syncthingtray_1.2.3.orig.tar.gz: syncthingtray-1.2.3/tray/translations/syncthingtray_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation>复制名字</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation>复制 ID</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation>复制 标签/ID</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation>重新扫描</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation>复制 标签/ID</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation>全部重新扫描</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation>日志</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation>显示内部错误</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation>从 Syncthing 断开连接</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation>启动器错误</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation>Syncthing 通知 - 点击解除</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation>Syncthing 设备想要连接 - 点击打开网页 UI</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing directory - click for web UI</source>
        <translation>新 Syncthing 目录 - 点击打开网页 UI</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation>Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="398"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="71"/>
        <location filename="../gui/traywidget.cpp" line="763"/>
        <location filename="../gui/traywidget.cpp" line="805"/>
        <source>Start</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="97"/>
        <location filename="../gui/traywidget.cpp" line="275"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="110"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="123"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="212"/>
        <source>Global</source>
        <translation>全局</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="219"/>
        <source>Global overall statistics</source>
        <translation>全局总体数据</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="222"/>
        <location filename="../gui/traywidget.ui" line="242"/>
        <location filename="../gui/traywidget.ui" line="293"/>
        <location filename="../gui/traywidget.ui" line="313"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="229"/>
        <source>Local</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="239"/>
        <source>Local overall statistics</source>
        <translation>本地总体数据</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="283"/>
        <source>In</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="290"/>
        <source>Incoming traffic</source>
        <translation>下载流量</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="300"/>
        <source>Out</source>
        <translation>上传</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="310"/>
        <source>Outgoing traffic</source>
        <translation>上传流量</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation>点击显示&lt;i&gt;新&lt;/i&gt;通知&lt;br&gt;
 对于&lt;i&gt;所有&lt;/i&gt;通知，请查看日志</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="354"/>
        <location filename="../gui/traywidget.cpp" line="154"/>
        <location filename="../gui/traywidget.cpp" line="318"/>
        <source>New notifications</source>
        <translation>新通知</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="384"/>
        <source>Directories</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="416"/>
        <source>Devices</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="448"/>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="476"/>
        <source>Recent changes</source>
        <translation>最后更改</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="512"/>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="522"/>
        <source>Dismiss</source>
        <translation>解除</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="126"/>
        <source>View own device ID</source>
        <translation>查看本设备 ID</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="131"/>
        <source>Restart Syncthing</source>
        <translation>重启 Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="136"/>
        <source>Show Syncthing log</source>
        <translation>显示 Syncthing 日志</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="141"/>
        <source>Rescan all directories</source>
        <translation>重新扫描全部目录</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="148"/>
        <source>Connection</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="170"/>
        <source>Show internal errors</source>
        <translation>显示内部错误</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="185"/>
        <source>Quit Syncthing Tray</source>
        <translation>退出 Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="373"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation>您真的想要重启 Syncthing 吗？</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="399"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation>未连接至 Syncthing，点击连接</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="411"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="412"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation>Syncthing 运行中，点击暂停全部设备</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="417"/>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="418"/>
        <source>At least one device is paused, click to resume</source>
        <translation>至少有一个设备已暂停，点击恢复</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="537"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation>指定的连接配置 &lt;em&gt;%1&lt;/em&gt; 没有定义，因此被忽略。</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="567"/>
        <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>本地设备上不存在目录 &lt;i&gt;%1&lt;/i&gt;。</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="578"/>
        <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>本地设备上不存在包含目录 &lt;i&gt;%1&lt;/i&gt;。</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="621"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="625"/>
        <source>Copy device ID</source>
        <translation>复制设备 ID</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="628"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="759"/>
        <location filename="../gui/traywidget.cpp" line="799"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="760"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation>停止通过托盘图标启动 Syncthing 实例</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="764"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation>使用设置中配置的内置启动器启动 Syncthing</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="59"/>
        <source>Unable to </source>
        <translation>无法 </translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="100"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation>系统托盘当前不可用。不过，您可以使用 --windowed 将托盘菜单作为常规窗口打开。也可以使用 --wait 启动 Syncthing Tray 以等待系统托盘可用，而不是显示此消息。</translation>
    </message>
    <message>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation type="vanished">首次使用 Syncthing Tray 时，您必须配置如何连接到 Syncthing。</translation>
    </message>
    <message>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="vanished">请注意，设置对话框允许从本地 Syncthing 配置导入 URL、凭据和 API 密钥。</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="127"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation>Qt 库没有使用托盘图标支持构建。不过，您可以使用 -w 将托盘菜单作为常规窗口打开。</translation>
    </message>
</context>
</TS>
